
#include <stdlib.h>
#include <stdio.h>
#include <math.h>
#include <string.h>
#include <unistd.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <signal.h>
#include <time.h>

#include <SDL/SDL.h>
#include <SDL/SDL_video.h>
#include <SDL/SDL_keysym.h>
#include <GL/gl.h>
#include <GL/glu.h>

#include "defines.h"
#include "sdl.h"


const SDL_VideoInfo *sdl_video_info = NULL;

/* quit key status */
extern int quit;

/* zooming */
extern float zoom;



int sdl_init(void) {

  if (SDL_Init(SDL_INIT_VIDEO | SDL_INIT_AUDIO | SDL_INIT_TIMER) < 0) {
    fprintf(stderr, "SDL_INIT: Video initialization failed: %s\n", SDL_GetError());
    return FAILED;
  }

  sdl_video_info = SDL_GetVideoInfo();

  if (SDL_SetVideoMode(SCREEN_X, SCREEN_Y, sdl_video_info->vfmt->BitsPerPixel, SDL_OPENGL) == 0) {
    fprintf(stderr, "SDL_INIT: Video mode initialization failed: %s\n", SDL_GetError());
    return FAILED;
  }

  SDL_EnableUNICODE(1);

  SDL_ShowCursor(SDL_DISABLE);
  SDL_SetEventFilter(sdl_filter_events);

  return SUCCEEDED;
}


int sdl_exit(void) {

  SDL_ShowCursor(SDL_ENABLE);
  SDL_Quit();

  return SUCCEEDED;
}


int sdl_keyboard_io(void) {

  SDL_Event event;
  SDLMod mod;
  int i;


  while (SDL_PollEvent(&event)) {
    switch (event.type) {

    /* mouse */
    case SDL_MOUSEBUTTONDOWN:
      /* pick up */
      if (event.button.button == 3)
	;
      break;

    /* key up */
    case SDL_KEYUP:
      break;

    /* key down */
    case SDL_KEYDOWN:
      i = event.key.keysym.sym;
      switch (event.key.keysym.sym) {
      case SDLK_i:
	zoom += 0.1;
	break;
      case SDLK_o:
	zoom -= 0.1;
	break;
      case SDLK_LEFT:
      case SDLK_a:
	break;
      case SDLK_RIGHT:
      case SDLK_d:
	break;
      case SDLK_UP:
      case SDLK_w:
	break;
      case SDLK_DOWN:
      case SDLK_s:
	break;
      case SDLK_ESCAPE:
	quit = YES;
	break;
      default:
	break;
      }
      break;
    }
  }

  mod = SDL_GetModState();

  return SUCCEEDED;
}


int sdl_filter_events(const SDL_Event *event) {

  int player_x, player_y;


  if (event->type == SDL_QUIT)
    return 1;

  if (event->type == SDL_MOUSEMOTION) {
    player_x += event->motion.xrel / (double)SCREEN_X * 360;
    player_y += event->motion.yrel / (double)SCREEN_Y * 360;
    if (player_x < 0)
      player_x += 360;
    if (player_x >= 360)
      player_x -= 360;
    if (player_y < -70)
      player_y = -70;
    if (player_y > 70)
      player_y = 70;
  }

  return 1;
}
